CarouselItem class

Constructors

CarouselItem({required String imageUrl, String? title, String? subtitle})

Properties

hashCode int
The hash code for this object.
no setterinherited
imageUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited